@@ -1,5 +1,7 @@
 setMethod("$",signature(x="pfilterd.pomp"),function (x,name) slot(x,name))
 setMethod("logLik",signature(object="pfilterd.pomp"),function(object,...)object@loglik)
+setMethod("eff.sample.size",signature(object="pfilterd.pomp"),function(object,...)object@eff.sample.size)
+setMethod("cond.logLik",signature(object="pfilterd.pomp"),function(object,...)object@cond.loglik)
 
 ## extract the prediction means
 setMethod(
@@ -31,4 +33,3 @@ setMethod(
             object@filter.mean[pars,]
           }
           )
-
