@@ -1,27 +1,24 @@
 require(pomp)
 
+## negative binomial measurement model
 dmeas <- "
-  lik = dbinom(reports,nearbyint(cases),rho,give_log);
+  double prob = theta/(theta+rho*incid);
+  lik = dnbinom(cases,theta,prob,give_log);
 "
 rmeas <- "
-  reports = rbinom(nearbyint(cases),rho);
+  double prob = theta/(theta+rho*incid);
+  cases = rnbinom(theta,prob);
 "
+## SIR process model with extra-demographic stochasticity
 step.fn <- '
   int nrate = 6;
   double rate[nrate];		// transition rates
   double trans[nrate];		// transition numbers
   double beta;			// transmission rate
   double dW;			// white noise increment
-  double period = 1.0;          // period of the seasonality
-  int nbasis = 3;               // number of seasonality basis functions
-  int deg = 3;                  // degree of the B-spline basis functions
-  double seasonality[nbasis];
   int k;
 
-  // compute transmission rate from seasonality
-  periodic_bspline_basis_eval(t,period,deg,nbasis,&seasonality[0]); // evaluate the periodic B-spline basis
-  for (k = 0, beta = 0; k < nbasis; k++) 
-    beta += (&beta1)[k]*seasonality[k];
+  beta = beta1*seas1+beta2*seas2+beta3*seas3;
 
   // compute the environmental stochasticity
   dW = rgammawn(beta_sd,dt);
@@ -44,7 +41,7 @@ step.fn <- '
   S += trans[0]-trans[1]-trans[2];
   I += trans[1]-trans[3]-trans[4];
   R += trans[3]-trans[5];
-  cases += trans[3];		// cases are cumulative recoveries
+  incid += trans[3];		// cases are cumulative recoveries
   if (beta_sd > 0.0) W += (dW-dt)/beta_sd; // increment has mean = 0, variance = dt
 '
 skel <- '
@@ -53,17 +50,9 @@ skel <- '
   double term[nrate];		// transition numbers
   double beta;			// transmission rate
   double dW;			// white noise increment
-  double period = 1.0;          // period of the seasonality
-  int nbasis = 3;
-  int deg = 3;
-  double seasonality[nbasis];
   int k;
   
-  // compute transmission rate from seasonality
-  if (nbasis <= 0) return;
-  periodic_bspline_basis_eval(t,period,deg,nbasis,&seasonality[0]); // evaluate the periodic B-spline basis
-  for (k = 0, beta = 0; k < nbasis; k++) 
-    beta += (&beta1)[k]*seasonality[k];
+  beta = beta1*seas1+beta2*seas2+beta3*seas3;
 
   // compute the transition rates
   rate[0] = mu*popsize;		// birth into susceptible class
@@ -85,52 +74,91 @@ skel <- '
   DS = term[0]-term[1]-term[2];
   DI = term[1]-term[3]-term[4];
   DR = term[3]-term[5];
-  Dcases = term[3];		// accumulate the new I->R transitions
+  Dincid = term[3];		// accumulate the new I->R transitions
   DW = 0;
 '
+## parameter transformations
+partrans <- "
+  double sum;
+  Tgamma = exp(gamma);
+  Tmu = exp(mu);
+  Tiota = exp(iota);
+  Tbeta1 = exp(beta1);
+  Tbeta2 = exp(beta2);
+  Tbeta3 = exp(beta3);
+  Tbeta_sd = exp(beta_sd);
+  Trho = expit(rho);
+  Ttheta = exp(theta);
+  TS_0 = exp(S_0);
+  TI_0 = exp(I_0);
+  TR_0 = exp(R_0);
+  sum = TS_0+TI_0+TR_0;
+  TS_0 /= sum;
+  TI_0 /= sum;
+  TR_0 /= sum;
+"
+paruntrans <- "
+  double sum;
+  Tgamma = log(gamma);
+  Tmu = log(mu);
+  Tiota = log(iota);
+  Tbeta1 = log(beta1);
+  Tbeta2 = log(beta2);
+  Tbeta3 = log(beta3);
+  Tbeta_sd = log(beta_sd);
+  Trho = logit(rho);
+  Ttheta = log(theta);
+  sum = S_0+I_0+R_0;
+  TS_0 = log(S_0/sum);
+  TI_0 = log(I_0/sum);
+  TR_0 = log(R_0/sum);
+"
+
+data(LondonYorke)
+
+cbind(
+      time=seq(from=1928,to=1934,by=0.01),
+      as.data.frame(
+                    periodic.bspline.basis(
+                                           x=seq(from=1928,to=1934,by=0.01),
+                                           nbasis=3,
+                                           degree=3,
+                                           period=1,
+                                           names="seas%d"
+                                           )
+                    )
+      ) -> covar
 
 pompBuilder(
             name="SIR",
-            data=data.frame(
-              time=seq(from=1/52,to=4,by=1/52),
-              reports=NA
-              ),
+            data=subset(
+              LondonYorke,
+              subset=town=="New York"&disease=="measles"&year>=1928&year<=1933,
+              select=c(time,cases)
+            ),
             times="time",
-            t0=0,
+            t0=1928,
             dmeasure=dmeas,
             rmeasure=rmeas,
             step.fn=step.fn,
             step.fn.delta.t=1/52/20,
             skeleton.type="vectorfield",
             skeleton=skel,
-            statenames=c("S","I","R","cases","W"),
+            covar=covar,
+            tcovar="time",
+            parameter.transform=partrans,
+            parameter.inv.transform=paruntrans,
+            statenames=c("S","I","R","incid","W"),
             paramnames=c(
-              "gamma","mu","iota","beta1","beta.sd","popsize","rho"
+              "gamma","mu","iota","beta1","beta2","beta3","beta.sd",
+              "popsize","rho","theta","S.0","I.0","R.0"
               ), 
-            zeronames=c("cases","W"),
-            logvar=c(
-              "gamma","mu","iota",
-              "beta1","beta2","beta3","beta.sd",
-              "S.0","I.0","R.0"
-              ),
-            logitvar="rho",
+            zeronames=c("incid","W"),
             comp.names=c("S","I","R"),
             ic.names=c("S.0","I.0","R.0"),
-            parameter.transform=function (params, logvar, logitvar, ic.names, ...) {
-              params[logvar] <- exp(params[logvar])
-              params[logitvar] <- plogis(params[logitvar])
-              params[ic.names] <- params[ic.names]/sum(params[ic.names])
-              params
-            },
-            parameter.inv.transform=function (params, logvar, logitvar, ic.names, ...) {
-              params[ic.names] <- params[ic.names]/sum(params[ic.names])
-              params[logvar] <- log(params[logvar])
-              params[logitvar] <- qlogis(params[logitvar])
-              params
-            },
             initializer=function(params, t0, comp.names, ic.names, ...) {
               x0 <- numeric(5)
-              names(x0) <- c("S","I","R","cases","W")
+              names(x0) <- c("S","I","R","incid","W")
               fracs <- params[ic.names]
               x0[comp.names] <- round(params['popsize']*fracs/sum(fracs))
               x0
@@ -140,10 +168,10 @@ pompBuilder(
 coef(po) <- c(
               gamma=26,mu=0.02,iota=0.01,
               beta1=120,beta2=140,beta3=100,
-              beta.sd=1e-3,
-              popsize=5e5,
-              rho=0.6,
-              S.0=26/120,I.0=0.001,R.0=1-26/120
+              beta.sd=0.01,
+              popsize=5e6,
+              rho=0.2,theta=0.001,
+              S.0=0.22,I.0=0.0018,R.0=0.78
               )
 
 ## compute a trajectory of the deterministic skeleton
@@ -152,7 +180,7 @@ X <- trajectory(po,hmax=1/52,as.data.frame=TRUE)
 toc <- Sys.time()
 print(toc-tic)
 
-plot(cases~time,data=X,type='l')
+plot(incid~time,data=X,type='l')
 
 ## simulate from the model
 tic <- Sys.time()
@@ -160,6 +188,21 @@ x <- simulate(po,nsim=3,as.data.frame=TRUE)
 toc <- Sys.time()
 print(toc-tic)
 
-plot(cases~time,data=x,col=as.factor(x$sim),pch=16)
+plot(incid~time,data=x,col=as.factor(x$sim),pch=16)
+
+coef(po) <- coef(
+                 traj.match(
+                            pomp(
+                                 window(po,end=1930)
+                                 ## window(po,end=1930),
+                                 ## measurement.model=cases~norm(mean=rho*incid,sd=100)
+                                 ),
+                            est=c("S.0","I.0","R.0"),
+                            transform=TRUE
+                            )
+                 )
+
+pf <- pfilter(po,Np=1000,max.fail=100)
+print(round(logLik(pf),1))
 
 dyn.unload("SIR.so")
