@@ -12,23 +12,21 @@ simulate(
               dmeasure="_ricker_poisson_dmeasure",
               skeleton.type="map",
               skeleton="_ricker_skeleton",
-              paramnames=c("log.r","sigma","phi"),
+              paramnames=c("r","sigma","phi"),
               statenames=c("N","e"),
               obsnames=c("y"),
               parameter.inv.transform=function(params,...) {
-                params <- c(params["log.r"],log(params[c("sigma","phi","N.0")]),params["e.0"])
-                names(params) <- c("log.r","log.sigma","log.phi","log.N.0","e.0")
+                params[c("r","sigma","phi","N.0")] <- log(params[c("r","sigma","phi","N.0")])
                 params
               },
               parameter.transform=function(params,...) {
-                params <- c(params["log.r"],exp(params[c("log.sigma","log.phi","log.N.0")]),params["e.0"])
-                names(params) <- c("log.r","sigma","phi","N.0","e.0")
+                params[c("r","sigma","phi","N.0")] <- exp(params[c("r","sigma","phi","N.0")])
                 params
               },
               PACKAGE="pomp"
               ),
          params=c(
-           log.r=3.8,
+           r=exp(3.8),
            sigma=0.3,
            phi=10,
            N.0=7,
